# encoding: utf-8

# File:	clients/oes-ldap_auto.ycp
# Package:	Configuration of oes-ldap
# Summary:	Client for autoinstallation
# Authors:	Novell YaST2 Development Team <support@novell.com>
#
# $Id: oes-ldap_auto.ycp,v 1.1.2.2 2005/08/02 23:30:06 mclark Exp $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of oes-ldap settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("oes-ldap_auto", [ "Summary", mm ]);
module Yast
  class OesLdapAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "oes-ldap"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellLDAP auto started")

      Yast.import "NovellLDAP"
      Yast.include self, "oes-ldap/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(NovellLDAP.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        NovellLDAP.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        #    NovellLDAP::autoyast_tool = true;  // FIXME: is this needed anymore?
        @ret = OesLdapAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = NovellLDAP.Import(@param)
      # Return actual state
      elsif @func == "Export"
        NovellLDAP.Read if NovellLDAP.Settings == nil || NovellLDAP.Settings == {}
        NovellLDAP.auto_clone = true
        @ret = NovellLDAP.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = NovellLDAP.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = NovellLDAP.Read
        Progress.set(@progress_orig)
      # Write givven settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        NovellLDAP.write_only = true
        @ret = NovellLDAP.Write
        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        @ret = NovellLDAP.globals_configured
      # Set modified flag
      # return boolean
      elsif @func == "SetModified"
        NovellLDAP.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("NovellLDAP auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::OesLdapAutoClient.new.main
