# encoding: utf-8

# File:	clients/oes-ldap_proposal.ycp
# Package:	Configuration of oes-ldap
# Summary:	Proposal function dispatcher.
# Authors:	Novell YaST2 Development Team <support@novell.com>
#
# $Id: oes-ldap_proposal.ycp,v 1.1.2.9 2005/07/28 19:52:54 rhaslam Exp $
#
# Proposal function dispatcher for oes-ldap configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class OesLdapProposalClient < Client
    def main

      textdomain "oes-ldap"

      Yast.import "NovellLDAP"
      Yast.import "Progress"
      #import "NovellPatterns";
      Yast.import "NovellAddonInstall"

      # Initialization - Arguments and Return Value
      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellLDAP proposal started in mode %1", @func)

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if @force_reset || !NovellLDAP.proposal_valid
          NovellLDAP.proposal_valid = true
          @progress_orig = Progress.set(false)
          NovellLDAP.Read
          Progress.set(@progress_orig)
        end
        if NovellLDAP.CheckLDAPBlocker(false)
          Ops.set(NovellAddonInstall.products_to_configure, "oes-ldap", true)
        end
        @sum = NovellLDAP.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("oes-ldap", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }
        if NovellLDAP.CheckLDAPBlocker(true)
          Builtins.y2milestone(
            "LDAP configuration is not complete. Blocker requested."
          )
          Ops.set(@ret, "errors", true)
        end
      # run the GUI
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("NovellLDAP proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "oes-ldap--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "oes-ldap", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "oes-ldap--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "oes-ldap", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = NovellLDAP.ExportSettings
          @seq = Convert.to_symbol(
            WFM.CallFunction("oes-ldap", [path(".propose")])
          )
          NovellLDAP.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2milestone("seq=%1", @seq)

          if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_SERVER_IP", "") == ""
            @sl = Ops.get_list(
              NovellLDAP.Settings,
              "CONFIG_LDAP_SERVERS_LIST",
              []
            )
            if Ops.greater_than(Builtins.size(@sl), 0)
              @sv = Ops.get(@sl, 0, [])
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVER_IP",
                Ops.get_string(@sv, 0, "")
              )
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVER_PORT",
                Ops.get_integer(@sv, 1, 389)
              )
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVER_SECURE_PORT",
                Ops.get_integer(@sv, 2, 636)
              )
            end
          end
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        # Determine if we need to be in the proposal screen
        # We do if any component uses LDAP for communication services
        # boolean isSelected = NovellLDAP::NeedLDAP();
        #     isSelected = isSelected && (NovellAddonInstall::IsProductSelected("edirectory") == false); // only display ldap dialog if edir is not selected
        @isSelected = true
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for NovellLDAP in proposals
            "rich_text_title" => _(
              "LDAP Configuration for Open Enterprise Services"
            ),
            # Menu title for NovellLDAP in proposals
            "menu_title"      => _(
              "LDAP Config&uration for Open Enterprise Services"
            ),
            "id"              => "oes-ldap"
          }
        else
          return {}
        end
      # write the proposal
      elsif @func == "Write"
        NovellLDAP.Write
        Progress.Finish
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2milestone("ret=%1", @ret)
      Builtins.y2milestone("NovellLDAP proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::OesLdapProposalClient.new.main
