# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	include/oes-ldap/helps.ycp
# Package:	Configuration of oes-ldap
# Summary:	Help texts of all the dialogs
# Authors:	Novell YaST2 Development Team Mark Clark mclark@novell.com, Denise Jewkes dburrell@novell.com
#
# $Id: helps.ycp,v 1.1.2.3 2005/07/21 21:54:25 Mark Clark Exp $
module Yast
  module OesLdapHelpsInclude
    def initialize_oes_ldap_helps(include_target)
      textdomain "oes-ldap"

      # All helps are here
      @HELPS = {
        # Read dialog help 1/2
        "read"                   => _(
          "<p><b><big>Initializing LDAP Configuration</big></b><br>\nPlease wait...<br></p>\n"
        ) +
          # Read dialog help 2/2
          _(
            "<p><b><big>Aborting Initialization</big></b><br>\nSafely stop the configuration utility by clicking <b>Abort</b> now.</p>\n"
          ),
        # Write dialog help 1/2
        "write"                  => _(
          "<p><b><big>Saving LDAP Configuration</big></b><br>\nPlease wait...<br></p>\n"
        ) +
          # Write dialog help 2/2
          _(
            "<p><b><big>Aborting the Save</big></b><br>\n" +
              "Stop the save procedure by clicking <b>Abort</b>.\n" +
              "This opens an additional dialog that indicates whether it is safe to do so.</p>\n"
          ),
        # Summary dialog help 1/3
        "summary"                => _(
          "<p><b><big>OES LDAP Configuration</big></b><br>\nConfigure LDAP servers here.</p>\n"
        ) +
          # Summary dialog help 2/3
          _(
            "<p><b><big>Adding an LDAP Server</big></b><br>\n" +
              "Select an LDAP server from the list of detected LDAP servers.\n" +
              "If your LDAP server was not autodetected, select <b>Other (not detected)</b>.\n" +
              "Then click <b>Configure</b>.</p>\n"
          ) +
          # Summary dialog help 3/3
          _(
            "<p><b><big>Editing</big></b><br>\n" +
              "Click <b>Edit</b> to open an additional dialog where you can change\n" +
              "the configuration.</p>\n"
          ),
        # Overview dialog help 1/3
        "Overview"               => _(
          "<p><b><big>OES LDAP Configuration Overview</big></b><br>\n" +
            "Obtain an report of configured LDAP servers for Open Enterprise Server. Additionally\n" +
            "edit their configuration.</p>\n"
        ) +
          # Overview dialog help 2/3
          _(
            "<p><b><big>Add</big></b><br>\nUse this option to add an LDAP server to the tree.</p>"
          ) +
          # Overview dialog help 3/3
          _(
            "<p><b><big>Editing or Deleting</big></b><br>\nTo modify the configuration of an LDAP server or to remove it from the tree, select an LDAP server. Then click <b>Edit</b> or <b>Delete</b>, as desired.</p>\n"
          ),
        # LDAP Server Configuration dialog help 1/6
        "ldap_server_config"     => _(
          "<p><b><big>Configured LDAP Servers</big></b><br>\nUse this dialog to specify eDirectory LDAP server information for the OES services you install on this server.</p>\n"
        ) +
          # LDAP Server Configuration dialog help 2/6
          _(
            "<p><b><big>eDirectory Tree Name</big></b><br>\nSpecify the eDirectory tree that you are installing this server into.</p>\n"
          ) +
          # LDAP Server Configuration dialog help 3/6
          _(
            "<p><b><big>Admin Name and Context</big></b><br>\nSpecify the fully distinguished, typeful name of a user with administrative rights in the tree. Use LDAP format.<br>For example, cn=admin,o=organization.</p>\n"
          ) +
          # LDAP Server Configuration dialog help 4/6
          _(
            "<p><b><big>Admin Password</big></b><br>\nSpecify the password for the eDirectory Admin user.</p>\n"
          ) +
          _(
            "<p><b><big>Common Proxy user context (conditional)</big></b><br>\nDuring LUM or NCS configuration, if you have not selected eDirectory service, then this field is displayed.</p>\n" +
            "Specify the context to create the Common proxy user.\n"
          ) +
          # LDAP Server Configuration dialog help 5/6
          _(
            "<p><b><big>Configured LDAP Servers</big></b><br>\n" +
              "The eDirectory LDAP servers listed in this table are servers that can be used to configure other OES services on this server. Each added server must have either the master or a read/write replica of the eDirectory tree. The first server added to the list becomes the default server for the installed and configured OES services to use.<p> \n" +
              "<p>If you are creating a new tree, the server you are installing has the master replica.</p>\n" +
              "<p>If you are installing into an existing tree, this server might not have a replica copied to it, depending on the tree configuration. For more information, see the documentation corresponding to your eDirectory version.</p>\n"
          ) +
          _(
            "<p><b><big>Add</big></b><br>\n" +
              "Click this option to add an eDirectory LDAP server to the Configured LDAP Servers table.</p>\n" +
              "<p>This opens an additional dialog where you can specify the IP address / hostname and LDAP port numbers for the servers you want to add. The local server IP address / hostname is shown by default.</p>\n" +
              "<p>If you are configuring a new eDirectory tree on this server, use the IP address / hostname of this server. If you installing this server in an existing eDirectory tree, specify the IP address / hostname of existing servers in the tree.</p> \n" +
              "<p>When you add an existing server in the eDirectory tree, it is listed as a Remote Server type.</p>\n"
          ) +
          # LDAP Server Configuration dialog help 6/6
          _(
            "<p><b><big>Delete</big></b><br>\nSelect an LDAP server to remove, then click this option.</p>\n"
          ),
        # Single selection box help 1/1
        "ServerListWidgetSingle" => _(
          "<p><b><big>%1</big></b><br>\n" +
            "The selected IP address / hostname is the default LDAP server for this service. If you do not want to use the default, select a different LDAP server in the list.</p>\n" +
            "<p>If you are installing into an existing tree, ensure that the server you select has a master replica or read/write replica of eDirectory. If you need to add another LDAP server to the list, add it using the LDAP Configuration for Open Enterprise Services dialog.</p>\n"
        ),
        # Combo box help 1/1
        "ServerListWidgetCombo"  => _(
          "<p><b><big>%1</big></b><br>\n" +
            "The IP address / hostname shown is the default LDAP server for this service. If you do not want to use the default, select a different LDAP server in the list.</p>\n" +
            "<p>If you are installing into an existing tree, ensure that the server you select has a master replica or read/write replica of eDirectory. If you need to add another LDAP server to the list, add it using the LDAP Configuration for Open Enterprise Services dialog.</p>\n"
        ),
        # Multi selection box help 1/1
        "ServerListWidgetMulti"  => _(
          "<p><b><big>%1</big></b><br>\n" +
            "The IP addresses and hostnames shown are the LDAP servers available for this service to use. Select an LDAP server from the list. If you want an additional level of redundancy, select more than one IP address / hostname.</p>\n" +
            "<p>Ensure that the servers you select have a master replica or read/write replica of eDirectory. If you need to add another LDAP server to the list, add it using the LDAP Configuration for Open Enterprise Services dialog.</p>\n"
        ),
        # Proxy User Dialog 1/7
        "proxy_user"             => _(
          "<p><b><big>OES Common Proxy User Information</big></b><br>\nUse this screen to set  the default common proxy user for the services that require proxy users.</p>\n"
        ) +
          # Proxy User Dialog 2/7
          _(
            "<p><b><big>Use Common Proxy User as Default for OES Products</big></b><br>\nSelecting this option will allow the user on this screen to be used as a default value for products that require proxy users.</p>\n"
          ) +
          # Proxy User Dialog 3/7
          _(
            "<p><b><big>OES Common Proxy User Name</big></b><br>\nSpecify the name of a fully distinguished User object that will be created. This will be the default common proxy user for the services that require proxy users.</p>\n"
          ) +
          # Proxy User Dialog 4/7
          _(
            "<p><b><big>OES Common Proxy User Password</big></b><br>\nSpecify the proxy users's password. This is the password of the user specified in the prior field.</p>\n"
          ) +
          # Proxy User Dialog 5/7
          _(
            "<p><b><big>Verify OES Common Proxy User Password</big></b><br>\nRetype the password to verify that you previously typed the intended password.</p>\n"
          ) +
          # Proxy User Dialog 6/7
          _(
            "<p><b><big>Assign Common Proxy Password Policy to Proxy User</big></b><br>\nAssign the user specified in the prior field to the Common Proxy Password Policy.</p>\n"
          ) +
          # Proxy User Dialog 7/7
          _(
            "<p><b><big>Note:</big></b><br>\nIf all fields are disabled, then the proxy user has already been set in the eDirectory install.</p>\n"
          )
      } 

      # EOF
    end
  end
end
