# encoding: utf-8

# File:	include/oes-ldap/wizards.ycp
# Package:	Configuration of oes-ldap
# Summary:	Wizards definitions
# Authors:	Novell YaST2 Development Team <support@novell.com>
#
# $Id: wizards.ycp,v 1.1.2.1 2005/06/25 23:39:25 rhaslam Exp $
module Yast
  module OesLdapWizardsInclude
    def initialize_oes_ldap_wizards(include_target)
      Yast.import "UI"

      textdomain "oes-ldap"

      Yast.import "Sequencer"
      Yast.import "Wizard"
      Yast.import "NovellLDAPUI"

      Yast.include include_target, "oes-ldap/complex.rb"
      Yast.include include_target, "oes-ldap/dialogs.rb"
    end

    # Add a configuration of oes-ldap
    # @return sequence result

    # Main workflow of the oes-ldap configuration
    # @return sequence result
    def MainSequence
      aliases = { "servers" => lambda { NovellLDAPUI.LDAPServersDialog } }

      sequence = {
        "ws_start" => "servers",
        "servers"  => { :abort => :abort, :next => :next }
      }
      Sequencer.Run(aliases, sequence)
    end

    # Whole configuration of oes-ldap
    # @return sequence result
    def OesLdapSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of oes-ldap but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def OesLdapAutoSequence
      # Initialization dialog caption
      caption = _("OesLdap Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
